@@ -40,6 +40,25 @@ run_config:
   # See https://en.wikipedia.org/wiki/ISO_8601 in section 'Duration'
   #max_cache_staleness: P0D
 
+  # Set to false to disable kfp artifacts exposal
+  # This setting can be useful if you don't want to store
+  # intermediate results in the MLMD
+  #store_kedro_outputs_as_kfp_artifacts: True
+
+  # Strategy used to generate Kubeflow pipeline nodes from Kedro nodes
+  # Available strategies:
+  #  * none (default) - nodes in Kedro pipeline are mapped to separate nodes
+  #                     in Kubeflow pipelines. This strategy allows to inspect
+  #                     a whole processing graph in Kubeflow UI and override
+  #                     resources for each node (because they are run in separate pods)
+  #                     Although, performance may not be optimal due to potential
+  #                     sharing of intermediate datasets through disk.
+  #  * full - nodes in Kedro pipeline are mapped to one node in Kubeflow pipelines.
+  #           This strategy mitigate potential performance issues with `none` strategy
+  #           but at the cost of degraded user experience within Kubeflow UI: a graph
+  #           is collapsed to one node.
+  #node_merge_strategy: none
+
   # Optional volume specification (only for non vertex-ai)
   volume:
 
@@ -115,6 +134,17 @@ class Config(object):
         return self._raw == other._raw
 
 
+class VertexAiNetworkingConfig(Config):
+    @property
+    def vpc(self):
+        return self._get_or_default("vpc", None)
+
+    @property
+    def host_aliases(self):
+        aliases = self._get_or_default("host_aliases", [])
+        return {alias["ip"]: alias["hostnames"] for alias in aliases}
+
+
 class VolumeConfig(Config):
     @property
     def storageclass(self):
@@ -195,6 +225,12 @@ class RunConfig(Config):
     def wait_for_completion(self):
         return bool(self._get_or_default("wait_for_completion", False))
 
+    @property
+    def store_kedro_outputs_as_kfp_artifacts(self):
+        return bool(
+            self._get_or_default("store_kedro_outputs_as_kfp_artifacts", True)
+        )
+
     @property
     def max_cache_staleness(self):
         return str(self._get_or_default("max_cache_staleness", None))
@@ -203,6 +239,22 @@ class RunConfig(Config):
     def ttl(self):
         return int(self._get_or_default("ttl", 3600 * 24 * 7))
 
+    @property
+    def vertex_ai_networking(self):
+        return VertexAiNetworkingConfig(
+            self._get_or_default("vertex_ai_networking", {})
+        )
+
+    @property
+    def node_merge_strategy(self):
+        strategy = str(self._get_or_default("node_merge_strategy", "none"))
+        if strategy not in ["none", "full"]:
+            raise ValueError(
+                f"Invalid {self._get_prefix()}node_merge_strategy: {strategy}"
+            )
+        else:
+            return strategy
+
     def _get_prefix(self):
         return "run_config."
 
